@@ -96,7 +96,7 @@ class plot:
         score_silhouette = silhouette_score(X_array, labels)
         plt.figure(figsize=(16, 8), dpi=100)
         plt.xlim(X_min , X_max)
-        plt.title("GMM: K=%d score_silhouette=%.2f" % (N_COMPONENTS, score_silhouette))
+        plt.title("GMM: K=%d score_silhouette=%.3f" % (N_COMPONENTS, score_silhouette))
         for k in range(N_COMPONENTS):
             datask = []
             for i in range(len(labels)):
@@ -115,6 +115,67 @@ class plot:
         plt.savefig(file_name + ".png", dpi=100)
         return True
 
+    def kmeansplot(data,feature_name,**kwargs):
+        N_CLUSTERS = int(kwargs['n_clusters'])     if 'n_clusters'    in kwargs else 2
+        X = np.array(data[feature_name])
+
+        X_min = min(X)
+        X_max = max(X)
+        X_range = X_max - X_min;
+        X_min     = int(kwargs['xmin'])     if 'xmin'    in kwargs else min(X) - X_range *0.05
+        X_max     = int(kwargs['xmax'])     if 'xmax'    in kwargs else max(X) + X_range *0.05
+        feature_bins = np.arange(np.min(X), np.max(X), 0.1)
+        
+        feature_mean = np.mean(X)
+        feature_std = np.std(X)
+        X_array = X.reshape(len(X),1)
+        
+        #调用kmeans类
+        clf = KMeans(n_clusters=N_CLUSTERS)
+        s = clf.fit(X_array)
+    
+    
+        #9个中心
+        #print(clf.cluster_centers_)
+        
+        #每个样本所属的簇
+        #print(clf.labels_)
+        
+        #用来评估簇的个数是否合适，距离越小说明簇分的越好，选取临界点的簇个数
+        #print(clf.inertia_)
+        
+        #进行预测
+        labels = clf.predict(X_array)
+        
+        #保存模型
+        #joblib.dump(clf , 'km.pkl')
+        
+        #载入保存的模型
+        #clf = joblib.load('km.pkl')
+        #print(gmm.get_params(True))
+
+        score_silhouette = silhouette_score(X_array, labels)
+        plt.figure(figsize=(16, 8), dpi=100)
+        plt.xlim(X_min , X_max)
+        plt.title("Kmeans: K=%d score_silhouette=%.3f inertia=%.3f" % (N_CLUSTERS, score_silhouette,clf.inertia_))
+        for k in range(N_CLUSTERS):
+            datask = []
+            for i in range(len(labels)):
+                if labels[i] == k:
+                    datask.append(X[i])
+            datask_np = np.array(datask)
+            cluster_mean = np.mean(datask_np)
+            cluster_std  = np.std(datask_np)
+            center = clf.cluster_centers_[k][0]
+            label_str = "mean=%.2f std=%.2f center=%.2f"%(cluster_mean,cluster_std,center)
+            sns.distplot(datask, bins=feature_bins,norm_hist=True,kde=True,kde_kws={ "label": label_str})
+            x,y = plot.normal_distribution(cluster_mean, cluster_std)
+            plt.plot(x, y, color = "black")
+        datetime_str = datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S%f')
+        file_name = hashlib.md5(datetime_str.encode(encoding='UTF-8')).hexdigest()
+        plt.savefig(file_name + ".png", dpi=100)
+        return True
+
 def main():
     ml3.intro()
 
